---
name: Bug report
about: Create a report to help us improve
title: ''
labels: bug
assignees: ''

---

PLEASE FILL OUT THE TEMPLATE

**Describe the bug**  
A clear and concise description of what the bug is and how to reproduce it. If applicable, add screenshots.

**Environment**
OS: (eg. Windows 10)
Python: (eg. 3.8.4)
IDE: (eg. PyCharm)

**Package versions**  
TO GET ALL RELEVANT PACKAGE VERSIONS, RUN THIS COMMAND IN BASH AND PASTE THE OUTPUT
pip freeze | grep -i "pyqt\|pandasgui\|plotly\|ipython\|jupyter\|notebook"

EXAMPLE OUTPUT
```
ipython==7.16.1
ipython-genutils==0.2.0
pandasgui==0.2.7
plotly==4.9.0
PyQt5==5.15.1
PyQt5-sip==12.8.1
PyQtWebEngine==5.15.1
```
